<?php

namespace Drupal\vault\Plugin;

/**
 * Class VaultLeaseStorage handles storage of leases in Drupal state api.
 *
 * @package Drupal\vault
 */
interface VaultLeaseStorageInterface {

  /**
   * Returns the data for a lease using Drupal's internal storage key.
   *
   * @param string $storage_key
   *   The storage key. Something like "key:key_machine_id".
   *
   * @return mixed|null
   *   The data stored in the lease. Null if no data can be returned.
   */
  public function getLease($storage_key);

  /**
   * Return all lease items.
   *
   * @return array
   *   Array of lease items.
   */
  public function getAllLeases();

  /**
   * Returns the lease ID for a given storage key.
   *
   * @param string $storage_key
   *   The storage key. Something like "key:key_machine_id".
   *
   * @return string|false
   *   The Vault lease ID.
   */
  public function getLeaseId($storage_key);

  /**
   * Deletes a lease from storage.
   *
   * @param string $storage_key
   *   The storage key. Something like "key:key_machine_id".
   */
  public function deleteLease($storage_key): void;

  /**
   * Stores a new lease.
   *
   * @param string $storage_key
   *   The storage key. Something like "key:key_machine_id".
   * @param string $lease_id
   *   The lease ID.
   * @param mixed $data
   *   The lease data.
   * @param int $expires
   *   The lease expiry (relative to current time in seconds).
   */
  public function setLease($storage_key, $lease_id, $data, $expires): void;

  /**
   * Updates the expiry of an existing lease.
   *
   * @param string $storage_key
   *   The storage key. Something like "key:key_machine_id".
   * @param int $new_expires
   *   The new lease expiry (relative to current time in seconds).
   */
  public function updateLeaseExpires($storage_key, $new_expires): void;

}
